@@ -34,6 +34,9 @@ class Sprite(DisplayObject, ChildInterface):
             js expression. It is not necessary to specify any
             string except when Sprite subclass will be instantiated.
         """
+        # Graphics sprite child cound of 1.
+        self._js_child_adjust_num = 1
+
         if variable_name is None:
             variable_name = expression_variables_util.\
                 get_next_variable_name(type_name='sprite')
